               job  unblock and print/punch
               ctl  6611
     *
     * Read cards that specify how to unblock files, from which tape,
     * and what to do (print and/or punch) them
     *
     * Column 1-3 -- record size as machine address
     * Column 4-6 -- blocking factor
     * Column 7   -- input tape number
     * Column 8   -- W print/punch with column 1 of the record meaning
     *                 blank -- single space
     *                 0     -- double space
     *                 1     -- top of page
     *                 &     -- punch first 80 columns
     *            -- P punch at most first 80 characters
     *            -- digit -- output tape number, unblocked
     * Column 9   -- Stacker selector for punching if not blank
     *
     * Halts indicated by A address register contents
     *  086 -- bad ,,WHAT,, column (not W, P or digit).
     *  66x -- tape error on unit x.
     *  777 -- halt after processing last card.  Start starts over.
     *
     rsize     equ  3                  1-3  record size
     blkfac    equ  6                  4-5  blocking factor
     intape    equ  7                  6    input tape number
     what      equ  8                  7    what to do
     stack     equ  9
     *
     x1        equ  089                Address in block & 1 of input rec
     x3        equ  099                Address of end of record area
     *                               Input block address is 2&x3
     *
     * Clear core down to rbuf
     *
     start     blc  done
               sw   rbuf
               sbr  clear&3,332        Start clearing at print area
     clear     cs   0-0                Clear a century
               sbr  clear&3            Keep track
               bw   clear,rbuf         Done when WM cleared
     *
     * Process the job specification
     *
               sw   1,rbuf
     k1        r
               bce  1,1,,              New program
               mn   intape,read&3
               sbr  x3,rbuf-1
               ma   rsize,x3           Address of end of record area
               lca  gmwm,1&x3          End of record buffer
               sbr  remain,0           Records remaining in block
               mn   stack,ss&4         Stacker selector
     *
     * Compute how to move from the record area to the print area
     *
               sbr  print&3,0&x3       End of input record for printing
               sbr  print&6,199
               ma   rsize,print&6      End of print line
               c    rsize,@134@        Q. Record longer than 133
               bh   *&8                No, use what was computed
               mcw  mprint&6,print&6   Use the 132-char default version
     *
     * Compute how to move from the record area to the punch area
     *
               sbr  punch&3,0&x3       End of input record for punching
               sbr  punch&6,100
               ma   rsize,punch&6      End of punch
               c    rsize,@081@        Q. Record longer than 80
               bh   *&8                No, use what was computed
               mcw  mpunch&6,punch&6   Use the 80-char default version
     *
     * Check ,,WHAT,, field
     *
               mn   what,write&3       in case it is output tape number
               bwz  loop,what,2        ,,what,, is a digit
               bce  loop,what,P
               ma   @001@,punch&3      Account for & in column 1 of rec
               bce  loop,what,W
               nop  086
               h                       ,,what,, is incorrect
               b    start
     loop      s    k1,remain
               bm   block,remain       Finished the block
               c    x1,endblk
               be   block              Finished short block
               ma   rsize,x1
               mcw  15999&x1,0&x3      Copy input record to output area
               bwz  write,what,2       ,,what,, is a digit
               bce  punch,what,P       Punch whole record
               bce  punch,rbuf,&       Punch starting in CC 2
               bce  top,rbuf,1
               bce  skip,rbuf,0
     *
     * Print a record
     *
     print     mcw  0-0,0-0
               w    loop
     top       ccb  print,1
     skip      ccb  print,j
     *
     * Punch a record
     *
     punch     mcw  0-0,0-0
               p
               bce  loop,stack,
     ss        ssb  loop,
     *
     * Read a block from tape
     *
     block     mcw  blkfac,remain
               mn   noise&7,14&x3
               mz   *-6,14&x3          A-zone to 12th char of block
               mz   *-6,noise&7          and D-modifier of test
               sbr  x1,2&x3            Input block buffer
     read      rt   0,2&x3             Read a block
     kp8       sbr  endblk
               bef  start
               ber  rderr
     noise     bce  read,14&x3,        Noise if still A-zone
               b    loop
     rderr     s    k1,inerr
               bm   haltin,inerr
     bspin     mn   read&3,*&4
               bsp  0
               b    read
     haltin    mcw  kp8,inerr          reset error tolerance to 8
               mn   read&3,*&4
               nop  660-0
               h
               b    bspin
     *
     * Write a record to tape
     *
     write     wt   0,rbuf
               ber  wterr
               b    loop
     wterr     s    k1,outerr
               bm   haltot,outerr
     bspot     mn   write&3,*&4
               bsp  0
               b    write
     haltot    mcw  kp8,outerr
               mn   write&3,*&4
               nop  660-0
               h
               skp  0                  Set the skip switch
               b    bspot
     *
     * Finished
     *
     done      nop  777
               h
               b    start
     *
     mprint    mcw  rbuf&132,332       Default move to print area
     mpunch    mcw  rbuf&79,180        Default move to punch area
     endblk    dcw  #3                 Addr of first char after input
     inerr     dcw  8                  Input error counter
     outerr    dcw  8                  Output error counter
     remain    dcw  #3                 Records remaining in block
               ltorg*
     gmwm      dcw  @}@
               org  *&x00
     rbuf      dcw  #1
               end  start
